## ----load data, results='hide', echo=FALSE, message=FALSE----------------
rm(list=ls(all=TRUE))

# Libraries ============================================================
library(plyr) # for split-app2ly functions
library(ggplot2) # for plotting
library(reshape2) # for data manipulation
library(mgcv) # for GAMs
library(openxlsx) # for reading Excel workbooks

setwd("~/Desktop/Dropbox/SMRU/MSFD/IA2017v2") 

wb <- loadWorkbook("OSPAR_MASTER_Jul2016.xlsx")
names(wb)

## ----pv abun sum, results='hide', echo=FALSE, message=FALSE--------------
# Need to sum maximum August count across AU

# Harbour seal (PV) abundance data =============================

head(pvdistrib <- readWorkbook(wb,"M3_Distribution_PV",check.names=FALSE))
  ddply(pvdistrib,c("Assessment_unit","Year"),summarise, count = sum(Count), n = length(Count))
    # add the Norway summary counts to Abundance worksheet
  
head(pvcount <- readWorkbook(wb,"M3_Abundance_PV",check.names=FALSE))
str(pvcount)
pvcount$Year <- as.integer(pvcount$Year)
unique(pvcount$Country)
  
  # Clean up and check===========================================
  # restrict the present analysis to August moult counts
  # and to the years 1992:2014
  # and remove non MSFD units (ie rest of Norway)
  unique(pvcount$Month)
  min(unique(pvcount$Year)); max(unique(pvcount$Year))
  pvcount <- pvcount[which(pvcount$Year > 1991 & pvcount$Year < 2015),] 
  unique(pvcount$Assessment_unit)
  pvcount <- pvcount[which(pvcount$Assessment_unit!="non-MSFD"),] # 21
  
  # most recent count for Ryan's maps and for weighting during integration
  ddply(pvcount,"Assessment_unit",function(df){
    max_yr <- max(df$Year)
    max_count <- df[which(df$Year==max_yr),"Count"]})
  
  # create a new column of 'reporting periods'. Starting with most recent year for which we have data from all CPs and work backwards in increments of 6 years
  pvcount$Period <- with(pvcount ,ifelse(Year %in% max(Year-6+1):max(Year),paste(paste(max(Year-6+1)),paste(max(Year)),sep="-"),ifelse(Year %in% max(Year-12+1):max(Year-6),paste(paste(max(Year-12+1)),paste(max(Year-6)),sep="-"),ifelse(Year %in% max(Year-18+1):max(Year-12),paste(paste(max(Year-18+1)),paste(max(Year-12)),sep="-"),ifelse(Year %in% max(Year-24+1):max(Year-18),paste(paste(max(Year-24+1)),paste(max(Year-18)),sep="-"),NA)))))
                                         
pvcount[,c("Year","Period")]

pvcount_sum <- pvcount
pvcount_sum <- rename(pvcount_sum,replace=c("Count"="Total"))
head(pvcount_sum)

## ----set up, results='hide', echo=FALSE, message=FALSE-------------------
  # Plot
  ggplot(pvcount_sum) + geom_point(aes(Year,Total,col=Period)) + facet_wrap(~Assessment_unit) + theme(axis.text.x = element_text(angle = 45,hjust=1)) + ggtitle("August harbour seal counts")

  ## Create a new workbook for results
  MSFD_tables <- createWorkbook()
  addWorksheet(MSFD_tables,"M3_PVmoult")
  
  # 21 Assessment Units
  AU <- unique(pvcount_sum$Assessment_unit)
 
  # Which assessment units do we have enough data to assess?
  ddply(pvcount_sum,"Assessment_unit",summarise,n_yr=length(unique(Year)))
    # I don't feel comfortably fitting a line through 3 data points so set the threshold to 4: note this excludes Wales, SW Scot, S Eng, Norway, NW Eng
  
   # Create space for each result
  (growth <- data.frame(AU=AU,
    t1rate=rep(NA,length(AU)), # average annual rate of growth in reporting round 2007:2012
    t1U=rep(NA,length(AU)), # upper 80% CI on annual rate
    t1L=rep(NA,length(AU)), # lower 80% CI on annual rate
    t1N=rep(NA,length(AU)), # number of survey years in period 2007:2012
    t2delta=rep(NA,length(AU)), # net % change in abundance since reference year, from model
    t2deltaU=rep(NA,length(AU)), # upper 80% CI on net change
    t2deltaL=rep(NA,length(AU)), # lower 80% CI on net change
    t2deltaOBS=rep(NA,length(AU)), # observed net change since reference
    t2N=rep(NA,length(AU)), # number of survey years since reference year
    baselineyr=rep(NA,length(AU)),
    last.count = rep(NA,length(AU)))) # most recent count


## ----delta, results='hide', echo=FALSE, message=FALSE--------------------
# Model each AU separately, where 4 or more surveys present in time series (this excludes Northwest England, South England, Southwest Scotland, & Wales)
    
# Input Assessment Unit of interest to 'data'
data <- "Belgium coast and Dutch Delta"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 

# Target 1: annual population growth rate in previous reporting round 2007-2012
  (t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson))
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)
  
# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  (t2<- glm(Total~Year,data=Data,family=quasipoisson)) # exponential increase
  
  # Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  DDfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  DDfig

## ----east scotland, results='hide', echo=FALSE, message=FALSE------------
# East Scotland
data <- "East Scotland"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) # looks like exponential growth 
  # As in Lonergan et al 2007 exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)
  
# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
  
  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  ESfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  ESfig

## ----france, results='hide', echo=FALSE, message=FALSE-------------------
# French North Sea & Channel coasts
data <- "French North Sea & Channel coasts"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) # exponential

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
  
  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  FRfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  FRfig

## ----kattegat, results='hide', echo=FALSE, message=FALSE-----------------
# Kattegat
data <- "Kattegat"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
# Teilmann et al 2010 undertook an analysis of Pv population growth rates Danish waters. They excluded counts in 1988 and 2002 owing to the PDV epidemic in those years. In addition, in KT, they excluded data from 2004 owing to disturbance. 

(Data <- subset(Data,!(Year %in% c(2002,2004))))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
 growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
   growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  # exponential to 1998; again from 2003
    t2 <- glm(Total~Year,data=Data,family=quasipoisson) # constant growth
    t2a<- glm(Total~Year + I(pmax(Year-1998,0))+ I(pmax(Year-2003,0)),data=Data,family=quasipoisson) # slope changes in 1997 and 2003
    t2b <- gam(Total ~ s(Year),data=Data,gamma=1.4,method="ML",family=quasipoisson)
    t2$dev; t2a$dev; t2b$dev 

  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2a,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  KTfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  KTfig

## ----limfjorden, results='hide', echo=FALSE, message=FALSE---------------
# Limfjorden 
data <- "Limfjorden"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
# Teilmann et al 2010 undertook an analysis of Pv population growth rates Danish waters. They excluded counts in 1988 and 2002 owing to the PDV epidemic in those years. In addition, in LF, they excluded data from 2000:2001 in one region owing to food limitation. 

(Data <- subset(Data,!(Year %in% c(2000,2001,2002))))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
 growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
   growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  # growth looks exponential to 1999 smooth from 2003 - 
    t2<- glm(Total~Year,data=Data,family=quasipoisson) # all years
    t2a<- glm(Total~I(-1*(Year<2000)) + Year + I(pmax(Year-2000,0)) + I(pmax(Year-2003,0)), data=Data,family=quasipoisson) # step 1999, diff slopes 
    t2b<- glm(Total~I(pmin(Year,2000))+I(pmax(Year,2000)),data=Data,family=quasipoisson) # slope change in 2000
    t2c <- gam(Total ~ s(Year),data=Data,gamma=1.4,method="ML",family=quasipoisson)
    t2$dev; t2a$dev; t2b$dev; t2c$dev 

    # Fits
 yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt2<-predict(t2c,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=max(Data$Year-6+1):max(Data$Year))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  LFfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none")  
  LFfig

## ----moray firth, results='hide', echo=FALSE, message=FALSE--------------
# Moray Firth 
data <- "Moray Firth"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  # NOTE: in 2005 the number I have from SMRU very different to number in Lonergan et al 2007
  # As in Lonergan et al 2007 exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
 growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # steady decline 
  t2a<- glm(Total~I(pmin(Year,2001))+I(pmax(Year,2001)),data=Data,family=quasipoisson) # step change in 2001
  t2b <- gam(Total ~ s(Year,k=4), data=Data, family=quasipoisson)
  t2$dev; t2a$dev; t2b$dev

  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2b,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  MFfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  MFfig

## ----orkney, results='hide', echo=FALSE, message=FALSE-------------------
# North Coast & Orkney 
data <- "North Coast & Orkney"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  # NOTE: count in 2005 only covers the north coast so is excluded in some SMRU plots (but is >7,000 animals)
  # As in Lonergan et al 2007 exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year,data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
   growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # steady decline 
  t2a<- glm(Total~I(pmin(Year,2004.5))+I(pmax(Year,2004.5)),data=Data,family=quasipoisson) # change in 2004
  t2b <- gam(Total ~ s(Year,k=4), data=Data, gamma=1.4, method="ML",family=quasipoisson)
  t2c<- glm(Total~I(pmin(Year,2005.5))+I(pmax(Year,2005.5)),data=Data,family=quasipoisson) # change in 2005
  t2d <- glm(Total~ I(-1*(Year<2005.5))+Year + I(pmax(Year-2005.5,0)),data=Data,family=quasipoisson) # step change in 2001, diff slopes pre and post 2002
  t2e <- glm(Total~ I(-1*(Year<2004.5))+Year + I(pmax(Year-2004.5,0)),data=Data,family=quasipoisson) # step change in 2001, diff slopes pre and post 2002
t2$dev; t2a$dev; t2b$dev; t2c$dev; t2d$dev; t2e$dev # t2b
  
    # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2b,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  OKfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  OKfig


## ----northeast england, results='hide', echo=FALSE, message=FALSE--------
# Northeast England 
data <- "Northeast England"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  # As in Lonergan et al 2007 exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # steady slope 
  t2a <- gam(Total ~ s(Year), data=Data, gamma=1.4, method="ML",family=quasipoisson)
  t2$dev; t2a$dev  

   # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  NEfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) +
    theme_bw() + theme(legend.position="none") 
  NEfig

## ----northern ireland, results='hide', echo=FALSE, message=FALSE---------
# Northern Ireland
data <- "Northern Ireland"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  
# Target 1: annual population growth rate in previous reporting round 
  # only 2 data points in last round
  growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014")) 

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
  
    # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure

  NIfig <- ggplot(Data) + 
    #geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    #geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) +
    theme_bw() + theme(legend.position="none") 
  NIfig

## ----shetland, results='hide', echo=FALSE, message=FALSE-----------------
# Shetland
data <- "Shetland"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  
# Target 1: annual population growth rate in previous reporting round 
  # only one count in previous round, cannot calculate t1
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
  
# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  # Lonergan et al 2007 found support for stability until 2001 followed by decline
   t2 <-  glm(Total~Year,data=Data,family=quasipoisson) # constant slope
    t2a <- glm(Total~1,data=Data,family=quasipoisson) # constant intercept
      t2b <- glm(Total~I(pmax(Year - 2001,0)),data=Data,family=quasipoisson) # constant until 2001, decline after
      t2$dev; t2a$dev; t2b$dev # here, simple constant slope minimizes deviance

      # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
    
  SHfig <- ggplot(Data) + 
    #geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    #geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  SHfig

## ----southeast england, results='hide', echo=FALSE, message=FALSE--------
# Southeast England
data <- "Southeast England"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
    # As in Lonergan et al 2007 exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  # Lonergan et al 2007 found support for different slopes '88-'02 and '02+ (but only data up to 2006). Looks like we have another slope change ~2006
   t2 <-  glm(Total~Year,data=Data,family=quasipoisson) # constant slope
    t2a <- gam(Total~s(Year),data=Data,family=quasipoisson) # smooth function year
      t2b <- glm(Total~ I(-1*(Year<2001)) + Year + I(pmax(Year - 2001,0))+I(pmax(Year-2005.5,0)),data=Data,family=quasipoisson) # slope changes in 2001 and 2005
      t2$dev; t2a$dev; t2b$dev # go with Mike's model here

      # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2b,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  SEfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  SEfig


## ----wadden sea, results='hide', echo=FALSE, message=FALSE---------------
# Wadden Sea
data <- "Wadden Sea"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
    # exclude surveys from 2002 PDV epidemic
  (Data <- subset(Data,!(Year %in% 2002)))

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- confint(t1,parm="Year",level=0.8)[2]*100
  growth[growth$AU==data,"t1L"] <- confint(t1,parm="Year",level=0.8)[1]*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2 <-  glm(Total~Year,data=Data,family=quasipoisson) # constant slope
      t2a <- glm(Total~ I(pmin(Year,2002.5))+I(pmax(Year,2002.5)),data=Data,family=quasipoisson) # slope changes in 2001
        t2a <- glm(Total~ I(-1*(Year<2003))+Year,data=Data,family=quasipoisson) # step change after 2002, common slopes
          t2c <- glm(Total~ I(-1*(Year<2003))+Year + I(pmax(Year-2003,0)),data=Data,family=quasipoisson) # step change in 2001, diff slopes pre and post 2002
      t2$dev; t2a$dev; t2b$dev; t2c$dev # t2c
  
        # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2c,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  WAfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  WAfig

## ----west scotland, results='hide', echo=FALSE, message=FALSE------------
# West Scotland
data <- "West Scotland"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
    
# Target 1: annual population growth rate in previous reporting round 
  growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) 
  
  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure

  WSfig <- ggplot(Data) + 
    #geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    #geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  WSfig

## ----western isles, results='hide', echo=FALSE, message=FALSE------------
# Western Isles
data <- "Western Isles"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
    
# Target 1: annual population growth rate in previous reporting round 
  # only 2 data points in this period
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
  
# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
   
  # Fits
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))
  # 80% confidence interval approximately 1.28 * s.e.
  (T2$upper80 <- T2$fit + 1.28*T2$se.fit) # upper 80% confidence limit
  (T2$lower80 <- T2$fit - 1.28*T2$se.fit) # lower 80% confidence limit
  
# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- ((tail(T2$upper80,1)-head(T2$lower80,1))/head(T2$lower80,1)*100) 
  growth[growth$AU==data,"t2deltaL"] <- ((tail(T2$lower80,1)-head(T2$upper80,1))/head(T2$upper80,1)*100) 
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  WIfig <- ggplot(Data) + 
    #geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    #geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Harbour seal count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  WIfig

## ----remainder, results='hide', echo=FALSE, message=FALSE----------------
data <- "Northern Skagerrak and Oslo Fjord"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
    
data <- "Northwest England"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
    
data <- "Norwegian west coast, south of 62N"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth

data <- "South England"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth

data <- "Southwest Scotland"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth
    
data <- "Wales"
Data <- pvcount_sum[which(pvcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
   growth[growth$AU==data,"t1N"] <- length(which(Data$Period=="2009-2014"))
   growth[growth$AU==data,"t2N"] <- length(unique(Data$Year))
   growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Total"]
    growth

## ----plot export, results='hide', echo=FALSE, message=FALSE--------------
pdf("MSFD_M3_pv.pdf")
DDfig;ESfig;FRfig;KTfig;LFfig;MFfig;OKfig;NEfig;NIfig;SHfig;SEfig;WAfig;WSfig;WIfig
dev.off()

## ----occupancy, results='hide', echo=FALSE-------------------------------
# Harbour seal abundance data ======================================================
# NB: German data for Wadden Sea calculations not included because no aggregating spatial units were provided
str(pvdistrib); summary(pvdistrib)
pvdistrib$Year <- as.integer(pvdistrib$Year)

# Clean up and check ===============================================================
  # restrict to August moult counts
  unique(pvdistrib$Month); unique(pvdistrib$Season); min(unique(pvcount$Year)); max(unique(pvcount$Year))
  
  # create a new column of 'reporting periods'. Starting with most recent year for which we have data from all CPs and work backwards in increments of 6 years
  pvdistrib$Period <- with(pvdistrib ,ifelse(Year %in% max(Year-6+1):max(Year),paste(paste(max(Year-6+1)),paste(max(Year)),sep="-"),ifelse(Year %in% max(Year-12+1):max(Year-6),paste(paste(max(Year-12+1)),paste(max(Year-6)),sep="-"),ifelse(Year %in% max(Year-18+1):max(Year-12),paste(paste(max(Year-18+1)),paste(max(Year-12)),sep="-"),ifelse(Year %in% max(Year-24+1):max(Year-18),paste(paste(max(Year-24+1)),paste(max(Year-18)),sep="-"),NA)))))

    # reclaculate the presence/absence column
  pvdistrib$Presence <- ifelse(pvdistrib$Count>0,1,0)
  
  # for each site/subarea, split into reporting periods and calculate the number of times the site was surveyed, and then how many times it was found occupied within those times it was surveyed
    # we aggregate across years within a reporting period because in the UK primarily (but also Norway) surveys are conducted on a piecemeal basis. i.e. not all AU subareas are surveyed in each year)
  head(temp <- ddply(pvdistrib,c("Assessment_unit","Site_name_ID","Period"),summarise,nsurv=length(unique(Year)),nocc=length(which(Presence==1))))
  
  # now split this df by AU and reporting period and calculate the number of unique sites that were surveyed and the number of sites found occupied, and proportion of occupied areas
  (pvdistrib_sum <- ddply(temp, c("Assessment_unit","Period"), summarise,nsites=length(which(nsurv>0)), nocc=length(which(nocc>0)),propocc=nocc/nsites))
  
 # subset to last two reporting rounds of interest
    (pvocc <- pvdistrib_sum[pvdistrib_sum$Period %in% c("2003-2008","2009-2014"),])

  # calculate change in occupany rate between periods in each AU
  (rolling <- ddply(pvocc,"Assessment_unit",summarise,occupancy=diff(propocc),survdiff=diff(nsites)))
  rolling <- rename(rolling,c("Assessment_unit"="AU"))
  
growth <- merge(growth,rolling,by="AU",all.x=TRUE)
growth

  # these metrics will be biased towards AUs with many subareas; where there are few (perhaps larger) subareas (e.g. Dutch Delta) losing one will equate to a big change in the metric

## ----shift, results='hide', echo=FALSE-----------------------------------
head(pvdistrib); unique(pvdistrib$Country) # no German data here because we have no subunits defined here, just points = small groups of animals. It would be inappropriate to assess distribution using those data.

# calculate the shift index by period. First cast the long table into wide format with a column for each spatial unit (colony). Count the number of times that subarea appears with a count in each period 1:4
head(tab1 <- dcast(pvdistrib,Period ~ Site_name_ID, value.var = "Count", fun.aggregate=mean)) # mean count of seals in each period in each site; NA = site was not surveyed
head(tabTF <- ifelse(tab1[,2:ncol(tab1)]>0,"TRUE","FALSE")) # Anytihng > 0 = presence; 0 = absence
head(prevtabTF <- head(rbind(NA, tabTF), -1)) # create a new table with pres/absence shifted down in order to compare one period with previous period

# compare two tables: melt back to long format, add AUs
head(df1 <- melt(tabTF,value.name = "presencet1")) # presence state at period i
head(df2 <- melt(prevtabTF,value.name = "presencet0")) # presence state in previous reporting round i-1
df1$presencet0 <- df2$presencet0
head(df1)
names(df1) <- c("periodN","Site_name_ID","timeB","timeA")
temp2 <- ddply(pvdistrib,c("Site_name_ID"),summarise,Assessment_unit=head(Assessment_unit,1))
head(presence <- merge(df1,temp2,by="Site_name_ID"))

# create column of 0 = not present in either time period; 1 = present in both time periods; +1 = new in the recent time period; -1 = present in previous time period; NA = not surveyed in one or both periods
presence$occ_status <- ifelse(presence$timeB=="FALSE"&presence$timeA=="FALSE","0",ifelse(presence$timeB=="FALSE"&presence$timeA=="TRUE","-1",ifelse(presence$timeB=="TRUE"&presence$timeA=="FALSE","+1",ifelse(presence$timeB=="TRUE"&presence$timeA=="TRUE","1",NA))))
head(presence)

# the '1s' here give us the intersection of occupancy for the two time periods: these are areas/sites occupied both in tA and tB. For shift index, we need number of TRUE (i.e. occupied) values for each AU in column timeB and time A
(shift <- ddply(presence,c("Assessment_unit","periodN"),summarise,A=length(which(timeA=="TRUE")),B=length(which(timeB=="TRUE")),AB=length(which(occ_status=="1")),lost=length(which(occ_status=="-1")),new=length(which(occ_status=="+1")),noteither=length(which(occ_status=="0"))))

  # intersection AB will always be 0 for period 1 because there is no previous period to compare it to. Can also count up the number of 'new' colonies or 'lost' colonies but we cannot say that much about this because the entire area was not necessairly surveyed completely. 

shift$shift_index <- (2*shift$AB)/(shift$A+shift$B) # if all same areas were occupied in both period A and period B then twice AB would be equal to A + B. Shift = 1
shift$periodN[shift$periodN=="1"] <- "1992-1996"
shift$periodN[shift$periodN=="2"] <- "1997-2002"
shift$periodN[shift$periodN=="3"] <- "2003-2008"
shift$periodN[shift$periodN=="4"] <- "2009-2014"
shift

shift <- shift[which(shift$periodN=="2009-2014"),] # extract data for most recent reporting round
(shift <- shift[,c("Assessment_unit","shift_index")])
shift <- rename(shift,c("Assessment_unit" = "AU"))
growth <- merge(growth,shift,by="AU",all.x=TRUE)
growth

## ----write tables, results='hide', echo=FALSE, message=FALSE-------------
str(growth); 
growth

writeDataTable(wb = MSFD_tables, sheet = 1, x = growth)
saveWorkbook(MSFD_tables,"MSFD_tables.xlsx",overwrite = TRUE)

# write a normal (non Markdown) R file:
library(knitr)
getwd()
file.exists("Rfile_A_M3PV_play.Rmd")
purl("Rfile_A_M3PV_play.Rmd")

