## ----load data, results='hide', echo=FALSE, message=FALSE----------------
rm(list=ls(all=TRUE))

# Libraries ================================================
library(plyr) # for split-app2ly functions
library(ggplot2) # for plotting
library(reshape2) # for data manipulation
library(mgcv) # for GAMs
library(openxlsx) # for reading Excel workbooks

setwd("~/Desktop/Dropbox/SMRU/MSFD/IA2017v2/Draft 20160721 v1.02") 
# set to your own working directory

wb <- loadWorkbook("20160721_Table_B_survey_data.xlsx")
names(wb)

## ----hg abun data, results='hide', echo=FALSE, message=FALSE-------------
# Grey seal abundance data ===============================
head(hgcount <- readWorkbook(wb,"M3_Abundance_HG",check.names=FALSE))
str(hgcount)
hgcount$Year <- as.integer(hgcount$Year)
  
  # Clean up and check ==============================================================
  # restrict to grey seal moult counts (file includes also summer counts)
  unique(hgcount$Month); unique(hgcount$Season)
  hgcount <- hgcount[which(hgcount$Season=="grey seal moult"),]
  min(unique(hgcount$Year)); max(unique(hgcount$Year))
  hgcount <- hgcount[which(hgcount$Year > 1991 & hgcount$Year < 2015),]
  
  # summarise: split by AU and year and calculate number of counts per year to check that we have only one. NB: Kattegate and Limfjord counts were calculated from raw datasets as mean of two highest counts (2-3 surveys per site). 
  (hgcount_sum <- ddply(hgcount,c("Assessment_unit","Year"),transform, Total=Count,N=length(Count)))
  
  # create a new column of 'reporting periods'. Starting with most recent year for which we have data from all CPs and work backwards in increments of 6 years
  hgcount_sum$Period <- with(hgcount_sum ,ifelse(Year %in% max(Year-6+1):max(Year),paste(paste(max(Year-6+1)),paste(max(Year)),sep="-"),ifelse(Year %in% max(Year-12+1):max(Year-6),paste(paste(max(Year-12+1)),paste(max(Year-6)),sep="-"),ifelse(Year %in% max(Year-18+1):max(Year-12),paste(paste(max(Year-18+1)),paste(max(Year-12)),sep="-"),ifelse(Year %in% max(Year-24+1):max(Year-18),paste(paste(max(Year-24+1)),paste(max(Year-18)),sep="-"),NA)))))
  
# MODELLED Grey seal abundance data ===========================================================
  # these numbers are output from Bayesian population model that includes data from across OSPAR regions II and III. It is based on methods described in Special Committee on Seals (SCOS) reports (available at www.smru.ac.uk). The analysis was done by Dr Deborah Russell (SMRU, St Andrews)
  # 'wo' = population without inclusion of summer population estimate
  # 'w' = population model constrained by estimated number of adults from summer counts
    hgmod <- read.csv("20160721_Table_C_Hg_modeloutput.csv",header=TRUE)
    str(hgmod)
    hgmod$years <- as.integer(hgmod$years)
    
    # restrict to 1992 - 2014
    hgmod <- hgmod[which(hgmod$years > 1991 & hgmod$years < 2015),]

  hgmod$Period <- with(hgmod ,ifelse(years %in% max(years-6+1):max(years),paste(paste(max(years-6+1)),paste(max(years)),sep="-"),ifelse(years %in% max(years-12+1):max(years-6),paste(paste(max(years-12+1)),paste(max(years-6)),sep="-"),ifelse(years %in% max(years-18+1):max(years-12),paste(paste(max(years-18+1)),paste(max(years-12)),sep="-"),ifelse(years %in% max(years-24+1):max(years-18),paste(paste(max(years-24+1)),paste(max(years-18)),sep="-"),NA)))))

## ----plot hg, results='hide', echo=FALSE, message=FALSE------------------

  # Plot grey seal moult data
  ggplot(hgcount_sum) + geom_point(aes(Year,Total,col=Period)) + facet_wrap(~Assessment_unit) + theme(axis.text.x = element_text(angle = 45,hjust=1)) + ggtitle("August grey seal counts")
    
  # How many years data for each AU? 
  ddply(hgcount_sum,"Assessment_unit",summarise,n=length(Total))
     
      # Assessment Units
  AU <- c(unique(hgcount_sum$Assessment_unit),"GNS&CS","GNS&CS - IndEst") # add row for total grey seal pop size model results in Greater North Sea and Celtic Sea
  
   # Create space for each result
  (growth <- data.frame(AU=AU,
    t1rate=rep(NA,length(AU)), # average annual rate of growth in reporting round 2009:2014
    t1U=rep(NA,length(AU)), # upper 80% CI on annual rate
    t1L=rep(NA,length(AU)), # lower 80% CI on annual rate
    t1N=rep(NA,length(AU)), # number of survey years in period 2009:2014
    t2delta=rep(NA,length(AU)), # net % change in abundance since reference year, from model
    t2deltaU=rep(NA,length(AU)), # upper 80% CI on net change
    t2deltaL=rep(NA,length(AU)), # lower 80% CI on net change
    t2deltaOBS=rep(NA,length(AU)), # observed net change since reference
    t2N=rep(NA,length(AU)), # number of survey years since reference year
    baselineyr=rep(NA,length(AU)),
    last.count = rep(NA,length(AU)))) # most recent count

## ----delta, results='hide', echo=FALSE, message=FALSE--------------------
# Model each AU separately, where 4 or more surveys present in time series
# Input Assessment Unit of interest to 'data'
data <- "Belgium coast and Dutch Delta"
Data <- hgcount_sum[which(hgcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
  # Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))

# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- (((tail(T2$fit,1)+tail(T2$se.fit,1)) -(head(T2$fit,1)-head(T2$se.fit,1)))/(head(T2$fit,1)-head(T2$se.fit,1))*100)
  growth[growth$AU==data,"t2deltaL"] <- (((tail(T2$fit,1)-tail(T2$se.fit,1)) -(head(T2$fit,1)+head(T2$se.fit,1)))/(head(T2$fit,1)+head(T2$se.fit,1))*100)
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Count"]
    growth
   
# Figure
    yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  DDfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Grey seal moult count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  DDfig

## ----france, results='hide', echo=FALSE, message=FALSE-------------------
# French North Sea & Channel coasts
data <- "French North Sea & Channel coasts"
Data <- hgcount_sum[which(hgcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) # exponential

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
  t2<- glm(Total~Year,data=Data,family=quasipoisson) # exponential increase
  # Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))

# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- (((tail(T2$fit,1)+tail(T2$se.fit,1)) -(head(T2$fit,1)-head(T2$se.fit,1)))/(head(T2$fit,1)-head(T2$se.fit,1))*100)

    growth[growth$AU==data,"t2deltaL"] <- (((tail(T2$fit,1)-tail(T2$se.fit,1)) -(head(T2$fit,1)+head(T2$se.fit,1)))/(head(T2$fit,1)+head(T2$se.fit,1))*100)
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Count"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))

  FRfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Grey seal moult count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  FRfig

## ----kattegat, results='hide', echo=FALSE, message=FALSE-----------------
# Kattegat 
data <- "Kattegat"
Data <- hgcount_sum[which(hgcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 

# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
    t2 <- glm(Total~Year,data=Data,family=quasipoisson) 
    
  # Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))

# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- (((tail(T2$fit,1)+tail(T2$se.fit,1)) -(head(T2$fit,1)-head(T2$se.fit,1)))/(head(T2$fit,1)-head(T2$se.fit,1))*100)

    growth[growth$AU==data,"t2deltaL"] <- (((tail(T2$fit,1)-tail(T2$se.fit,1)) -(head(T2$fit,1)+head(T2$se.fit,1)))/(head(T2$fit,1)+head(T2$se.fit,1))*100)
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Count"]
    growth

# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))
   
  KTfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Grey seal moult count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  KTfig

## ----wadden sea, results='hide', echo=FALSE, message=FALSE---------------
# Wadden Sea
data <- "Wadden Sea"
Data <- hgcount_sum[which(hgcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  
# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
   t2 <- glm(Total~Year,data=Data,family=quasipoisson) 
  
# Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))

# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- (((tail(T2$fit,1)+tail(T2$se.fit,1)) -(head(T2$fit,1)-head(T2$se.fit,1)))/(head(T2$fit,1)-head(T2$se.fit,1))*100)

    growth[growth$AU==data,"t2deltaL"] <- (((tail(T2$fit,1)-tail(T2$se.fit,1)) -(head(T2$fit,1)+head(T2$se.fit,1)))/(head(T2$fit,1)+head(T2$se.fit,1))*100)
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Count"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))
   
  WAfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Grey seal moult count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  WAfig

## ----wadden sea - NL, results='hide', echo=FALSE, message=FALSE----------
# Wadden Sea - NL only
data <- "Wadden Sea - NL"
Data <- hgcount_sum[which(hgcount_sum$Assessment_unit == data),]
ggplot(Data) + geom_point(aes(Year,Total,col=Period)) 
  
# Target 1: annual population growth rate in previous reporting round 
  t1 <- glm(Total~Year, data=subset(Data,Period=="2009-2014"),family=quasipoisson)
  summary(t1) 
  growth[growth$AU==data,"t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU==data,"t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU==data,"t1N"] <- nobs(t1)

# Target 2: change in abundance since reference (1992 or earliest) year
  # Model(s)  
   t2 <- glm(Total~Year,data=Data,family=quasipoisson) 
  
# Fit(s)  
  yr<-data.frame(Year=min(Data$Year):max(Data$Year))
  pt2<-predict(t2,se=TRUE,type="response",newdata=yr)
  (T2<- data.frame(yr,pt2))

# Calculate observed and mean fitted delta change
    growth[growth$AU==data,"t2deltaOBS"] <- with(Data,(((tail(Total,1)-head(Total,1))/head(Total,1)*100)))
    growth[growth$AU==data,"t2delta"] <- ((tail(T2$fit,1)-head(T2$fit,1))/head(T2$fit,1)*100)
    growth[growth$AU==data,"t2deltaU"] <- (((tail(T2$fit,1)+tail(T2$se.fit,1)) -(head(T2$fit,1)-head(T2$se.fit,1)))/(head(T2$fit,1)-head(T2$se.fit,1))*100)

    growth[growth$AU==data,"t2deltaL"] <- (((tail(T2$fit,1)-tail(T2$se.fit,1)) -(head(T2$fit,1)+head(T2$se.fit,1)))/(head(T2$fit,1)+head(T2$se.fit,1))*100)
    growth[growth$AU==data,"t2N"] <- nobs(t2)
    growth[growth$AU==data,"baselineyr"] <- min(Data$Year)
    growth[growth$AU==data,"last.count"] <- Data[which(Data$Year==max(Data$Year)),"Count"]
    growth
   
# Figure
  yr1 <-data.frame(Year=min(Data[which(Data$Period=="2009-2014"),"Year"]):max(Data[which(Data$Period=="2009-2014"),"Year"]))
  pt1<-predict(t1,se=TRUE,type="response",newdata=yr1)
  (T1 <- data.frame(yr1,pt1))
   
  WANLfig <- ggplot(Data) + 
    geom_line(data=T1,aes(Year,fit), lty="dotdash", lwd=1) +
    geom_ribbon(data=T1,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="light blue", alpha=0.75) +
  geom_line(data=T2,aes(Year,fit), lty="dotted", lwd=1) +
    geom_ribbon(data=T2,aes(Year,ymax=fit+1.28*se.fit,ymin=fit-1.28*se.fit), fill="grey", alpha=0.5) +
    geom_point(data=Data, aes(x=Year, y=Total, col=Period)) + scale_x_continuous(limits=c(1992,2014),breaks=c(1995,2000,2005,2010)) + 
    scale_color_manual(values=c("1991-1996"="#e7298a","1997-2002"="#7570b3", "2003-2008"="#d95f02","2009-2014"="#1b9e77")) + 
    ylab("Grey seal moult count") + xlab("") +
    ggtitle(data) + 
    theme_bw() + theme(legend.position="none") 
  WANLfig

## ----plot export, results='hide', echo=FALSE, message=FALSE--------------
pdf("Figure_D_Hg_models.pdf")
DDfig;FRfig;KTfig;WAfig;WANLfig
dev.off()

## ----occupancy, results='hide', echo=FALSE-------------------------------
# Grey seal distribution data =============================================================
head(hgdistrib <- readWorkbook(wb,"M3_Distribution_HG",check.names=FALSE))
str(hgdistrib); summary(hgdistrib)
hgdistrib$Year <- as.integer(hgdistrib$Year)

# Clean up and check ===============================================================
  # restrict to August moult counts and 1992-2014
  unique(hgdistrib$Month); unique(hgdistrib$Season)
  hgdistrib <- hgdistrib[which(hgdistrib$Season=="grey seal moult"),]
  max(hgdistrib$Year); min(hgdistrib$Year)
  hgdistrib <- hgdistrib[which(hgdistrib$Year > 1991 & hgdistrib$Year < 2015),]

# create a new column of 'reporting periods'. Starting with most recent year for which we have data from all CPs and work backwards in increments of 6 years
  hgdistrib$Period <- with(hgdistrib ,ifelse(Year %in% max(Year-6+1):max(Year),paste(paste(max(Year-6+1)),paste(max(Year)),sep="-"),ifelse(Year %in% max(Year-12+1):max(Year-6),paste(paste(max(Year-12+1)),paste(max(Year-6)),sep="-"),ifelse(Year %in% max(Year-18+1):max(Year-12),paste(paste(max(Year-18+1)),paste(max(Year-12)),sep="-"),ifelse(Year %in% max(Year-24+1):max(Year-18),paste(paste(max(Year-24+1)),paste(max(Year-18)),sep="-"),NA)))))
  
      # reclaculate the presence/absence column
  hgdistrib$Presence <- ifelse(hgdistrib$Count>0,1,0)
  
  # for each site/subarea, split into reporting periods and calculate the number of time the site was surveyed, and then how many times it was found occupied within those times it was surveyed
  head(temp <- ddply(hgdistrib,c("Assessment_unit","Site_name_ID","Period"),summarise,nsurv=length(unique(Year)),nocc=length(which(Presence==1))))
  
  # now split this df by AU and reporting period and calculate the number of unique sites that were surveyed and the number of sites found occupied, and proportion of occupied areas
  (hgdistrib_sum <- ddply(temp, c("Assessment_unit","Period"), summarise,nsites=length(which(nsurv>0)), nocc=length(which(nocc>0)),propocc=nocc/nsites))
  
# subset to last two reporting rounds of interest
  (hgocc <- hgdistrib_sum[hgdistrib_sum$Period %in% c("2003-2008","2009-2014"),])

  # calculate change in occupany rate between periods in each AU
  (rolling <- ddply(hgocc,"Assessment_unit",summarise,occupancy=diff(propocc),survdiff=diff(nsites)))
  rolling <- rename(rolling,c("Assessment_unit"="AU"))
  
growth <- merge(growth,rolling,by="AU",all.x=TRUE)
growth

  # these metrics will be biased towards AUs with many subareas; where there are few (perhaps larger) subareas (e.g. Dutch Delta) losing one will equate to a big change in the metric

  # do not report wadden sea metric as survey effort changed 

## ----shift, results='hide', echo=FALSE-----------------------------------
head(hgdistrib); unique(hgdistrib$Country) # no German data here 

# calculate the shift index by period. First cast the long table into wide format with a column for each spatial unit (colony). Count the number of times that subarea appears with a count in each period 1:4
head(tab1 <- dcast(hgdistrib,Period ~ Site_name_ID, value.var = "Count", fun.aggregate=mean)) # mean count of seals in each period in each site; NA = site was not surveyed
head(tabTF <- ifelse(tab1[,2:ncol(tab1)]>0,"TRUE","FALSE")) # Anytihng > 0 = presence; 0 = absence
head(prevtabTF <- head(rbind(NA, tabTF), -1)) # create a new table with pres/absence shifted down in order to compare one period with previous period

# compare two tables: melt back to long format, add AUs
head(df1 <- melt(tabTF,value.name = "presencet1")) # presence state at period i
head(df2 <- melt(prevtabTF,value.name = "presencet0")) # presence state in previous reporting round i-1
df1$presencet0 <- df2$presencet0
head(df1)
names(df1) <- c("periodN","Site_name_ID","timeB","timeA")
temp2 <- ddply(hgdistrib,c("Site_name_ID"),summarise,Assessment_unit=head(Assessment_unit,1))
head(presence <- merge(df1,temp2,by="Site_name_ID"))

# create column of 0 = not present in either time period; 1 = present in both time periods; +1 = new in the recent time period; -1 = present in previous time period; NA = not surveyed in one or both periods
presence$occ_status <- ifelse(presence$timeB=="FALSE"&presence$timeA=="FALSE","0",ifelse(presence$timeB=="FALSE"&presence$timeA=="TRUE","-1",ifelse(presence$timeB=="TRUE"&presence$timeA=="FALSE","+1",ifelse(presence$timeB=="TRUE"&presence$timeA=="TRUE","1",NA))))
head(presence)

# the '1s' here give us the intersection of occupancy for the two time periods: these are colonies were occupied both in tA and tB. For shift index, we need number of TRUE (i.e. occupied) values for each AU in column timeB and time A
(shift <- ddply(presence,c("Assessment_unit","periodN"),summarise,A=length(which(timeA=="TRUE")),B=length(which(timeB=="TRUE")),AB=length(which(occ_status=="1")),lost=length(which(occ_status=="-1")),new=length(which(occ_status=="+1")),noteither=length(which(occ_status=="0"))))

  # intersection AB will always be 0 for period 1 because there is no previous period to compare it to. Can also count up the number of 'new' colonies or 'lost' colonies but we cannot say that much about this because the entire area was not necessairly surveyed completely. 

shift$shift_index <- (2*shift$AB)/(shift$A+shift$B) # if all same areas were occupied in both period A and period B then twice AB would be equal to A + B. Shift = 1
shift$periodN[shift$periodN=="1"] <- "1992-1996"
shift$periodN[shift$periodN=="2"] <- "1997-2002"
shift$periodN[shift$periodN=="3"] <- "2003-2008"
shift$periodN[shift$periodN=="4"] <- "2009-2014"
shift

shift <- shift[which(shift$periodN=="2009-2014"),] # extract data for most recent reporting round
(shift <- shift[,c("Assessment_unit","shift_index")])
shift <- rename(shift,c("Assessment_unit" = "AU"))
growth <- merge(growth,shift,by="AU",all.x=TRUE)
growth

## ----total population, results='hide', echo=FALSE------------------------
head(Data <- hgmod)
ggplot(Data) + geom_point(aes(years,mean_wo_ind,col=Period))  + geom_point(aes(years,mean_w_ind,col=Period))  
  
# Target 1: annual population growth rate in previous reporting round 
  # without summer counts
  t1 <- glm(mean_wo_ind~years, data=subset(Data,years > max(years-6)),family=quasipoisson)
  summary(t1) 
  growth[growth$AU=="GNS&CS","t1rate"] <- (summary(t1)$coef[2])*100
  growth[growth$AU=="GNS&CS","t1U"] <- (summary(t1)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU=="GNS&CS","t1L"] <- (summary(t1)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU=="GNS&CS","t1N"] <- nobs(t1)

# with summer counts
  t1a <- glm(mean_w_ind~years, data=subset(Data,years > max(years-6)),family=quasipoisson)
  summary(t1a) 
  growth[growth$AU=="GNS&CS - IndEst","t1rate"] <- (summary(t1a)$coef[2])*100
  growth[growth$AU=="GNS&CS - IndEst","t1U"] <- (summary(t1a)$coef[2] + summary(t1)$coef[2,2])*100
  growth[growth$AU=="GNS&CS - IndEst","t1L"] <- (summary(t1a)$coef[2] - summary(t1)$coef[2,2])*100
  growth[growth$AU=="GNS&CS - IndEst","t1N"] <- nobs(t1a)
  growth
  
# Target 2: change in abundance since reference (1992 or earliest) year
# with out independent estimate
  # mean
    growth[growth$AU=="GNS&CS","t2delta"] <- with(Data,(tail(mean_wo_ind,1)-head(mean_wo_ind,1))/head(mean_wo_ind,1)*100)
  # upper  
    growth[growth$AU=="GNS&CS","t2deltaU"] <- with(Data,((tail(uCI_wo_ind,1)-head(lCI_wo_ind,1))/head(lCI_wo_ind,1))*100)
  # lower
    growth[growth$AU=="GNS&CS","t2deltaL"] <- with(Data,(tail(lCI_wo_ind,1)-head(uCI_wo_ind,1))/(head(uCI_wo_ind,1))*100)
    
    growth[growth$AU=="GNS&CS","baselineyr"] <- min(Data$years)
    growth[growth$AU=="GNS&CS","last.count"] <- Data[which(Data$years==max(Data$years)),"mean_wo_ind"]
    growth
    
# with independent estimate
  # mean
    growth[growth$AU=="GNS&CS - IndEst","t2delta"] <- with(Data,(tail(mean_w_ind,1)-head(mean_w_ind,1))/head(mean_w_ind,1)*100)
  # upper  
    growth[growth$AU=="GNS&CS - IndEst","t2deltaU"] <- with(Data,((tail(uCI_w_ind,1)-head(lCI_w_ind,1))/head(lCI_w_ind,1))*100)
  # lower
    growth[growth$AU=="GNS&CS - IndEst","t2deltaL"] <- with(Data,(tail(lCI_w_ind,1)-head(uCI_w_ind,1))/(head(uCI_w_ind,1))*100)
    
    growth[growth$AU=="GNS&CS - IndEst","baselineyr"] <- min(Data$years)
    growth[growth$AU=="GNS&CS - IndEst","last.count"] <- Data[which(Data$years==max(Data$years)),"mean_w_ind"]
    growth
    
# Figure -
    # stack the data
    library(scales)
    wo <- Data[,2:5]
    w <- Data[,c(2,6:8)]
    wo$type <- "without indepdendent estimate"
    w$type <- "with independent estimate"
    colnames(wo) <- c("years","mean","lower","upper","type")
    colnames(w) <- c("years","mean","lower","upper","type")
    head(hgall <- rbind(wo,w))
    
    # data.frame of independent estimate (2008) from HG summer counts
    ind <- data.frame(x=2008,y=102210,ymax=120180,ymin=84221,type="with independent estimate")
    
    HGtot <- ggplot(hgall) + 
    geom_line(aes(years,mean),lty="dashed") +
    geom_ribbon(aes(x=years,ymax=upper,ymin=lower),fill="light blue",alpha=0.5) +
    #geom_point(aes(x=2008, y=102210),size=3) +
    #
    ylab("Adult grey seals") + xlab("Year") +
    theme_bw() + theme(legend.position="none") +   scale_x_continuous(limits=c(1992,2012),breaks=c(1995,2000,2005,2010)) +   scale_y_continuous(breaks=c(100000,200000,300000,400000),labels=comma) +
      facet_wrap(~type) +
      geom_point(data=ind,aes(x=x,y=y),size=3) +
      geom_errorbar(data=ind,aes(x=x,ymax=ymax,ymin=ymin),width=0)
  HGtot

## ----write tables, results='hide', echo=FALSE, message=FALSE-------------
pdf("Figure_2.pdf")
HGtot
dev.off()

write.csv(growth, "resultsM3HG.csv")

# write a normal (non Markdown) R file:
library(knitr)
getwd()
file.exists("20170721_Rfile_B_M3HG.Rmd")
purl("Rfile_B_M3HG_play.Rmd")

